#
# spec file for package perf
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perf
%define version %(rpm -q --qf '%{VERSION}' kernel-source)
Version:        %{version}
Release:        lp152.21.3.1
Summary:        Performance Monitoring Tools for Linux
License:        GPL-2.0-only
Group:          Development/Tools/Debuggers
Url:            https://perf.wiki.kernel.org/
BuildRequires:  asciidoc
BuildRequires:  audit-devel
BuildRequires:  binutils-devel
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gtk2-devel
BuildRequires:  kernel-source >= 2.6.31
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
BuildRequires:  python3-devel
BuildRequires:  xz-devel
%ifarch aarch64 ia64 x86_64 ppc64 ppc64le ppc %sparc
BuildRequires:  libnuma-devel
%endif
%ifarch s390x s390
%define         _perf_unwind NO_LIBUNWIND=1
%else
%define         _perf_unwind %{nil}
BuildRequires:  libunwind-devel
%endif
BuildRequires:  newt-devel
BuildRequires:  openssl-devel
BuildRequires:  xmlto
BuildRequires:  zlib-devel
# dl_open requirement so not autodetected
%ifarch ppc64 ppc64le
Requires:       libebl
%endif
%{perl_requires}
%{?libperl_requires}
# upstream patches
Patch1:         perf-tools-add-itrace-option-o-to-synthesize-aux-output-events.patch
Patch2:         perf-tools-add-aux-output-config-term.patch
Patch3:         perf-tools-add-aux_output-attribute-flag.patch
Patch4:         perf-intel-pt-process-options-for-pebs-event-synthesis.patch
Patch5:         perf-intel-pt-add-brief-documentation-for-pebs-via-intel-pt.patch
Patch6:         perf-c2c-fix-report-with-offline-cpus.patch
Patch7:         perf-c2c-display-proper-cpu-count-in-nodes-column.patch
Patch8:         perf-vendor-events-amd-remove-redundant.patch
Patch9:         perf-list-allow-plurals-for-metric-metricgroup.patch
Patch10:        perf-vendor-events-remove-p8-hw-events-which-are-not-supported.patch
Patch11:        perf-vendor-events-s390-add-json-transaction-for-machine-type-8561.patch
Patch12:        perf-vendor-events-s390-use-s390-machine-name-instead-of-type-8561.patch
Patch13:        perf-script-allow-time-with-reltime.patch
Patch14:        perf-test-report-failure-for-mmap-events.patch
Patch15:        perf-vendor-events-arm64-fix-hisi-hip08-ddrc-pmu-eventname.patch
Patch16:        perf-probe-fix-to-find-range-only-function-instance.patch
Patch17:        perf-probe-walk-function-lines-in-lexical-blocks.patch
Patch18:        perf-probe-fix-wrong-address-verification.patch
Patch19:        perf-probe-fix-to-show-ranges-of-variables-in-functions-without-entry_pc.patch
Patch20:        perf-probe-fix-to-show-inlined-function-callsite-without-entry_pc.patch
Patch21:        perf-probe-fix-to-show-function-entry-line-as-probe-able.patch
Patch22:        perf-probe-fix-to-probe-an-inline-function-which-has-no-entry-pc.patch
Patch23:        perf-probe-fix-to-probe-a-function-which-has-no-entry-pc.patch
Patch24:        perf-probe-fix-to-list-probe-event-with-correct-line-number.patch
Patch25:        perf-jevents-fix-resource-leak-in-process_mapfile-and-main.patch
Patch26:        perf-probe-skip-end-of-sequence-and-non-statement-lines.patch
Patch27:        perf-probe-skip-overlapped-location-on-searching-variables.patch
Patch28:        perf-probe-fix-to-show-calling-lines-of-inlined-functions.patch
Patch29:        perf-probe-filter-out-instances-except-for-inlined-subroutine-and-subprogram.patch
Patch30:        perf-tests-fix-out-of-bounds-memory-access.patch
Patch31:        perf-map-no-need-to-adjust-the-long-name-of-modules.patch
Patch32:        perf-callchain-fix-segfault-in-thread__resolve_callchain_sample.patch
Patch33:        perf-diff-use-llabs-with-64-bit-values.patch
Patch34:        perf-script-fix-brstackinsn-for-auxtrace.patch
Patch35:        perf-regs-make-perf_reg_name-return-unknown-instead-of-null.patch
Patch36:        perf-vendor-events-s390-remove-name-from-l1d_ro_excl_writes-description.patch
Patch37:        perf-report-fix-incorrectly-added-dimensions-as-switch-perf-data-file.patch
Patch38:        perf-hists-fix-variable-name-s-inconsistency-in-hists__for_each-macro.patch
Patch39:        perf-hists-browser-restore-esc-as-zoom-out-of-dso-thread-etc.patch
Patch40:        perf-ui-gtk-add-missing-zalloc-object.patch
Patch41:        perf-stat-don-t-report-a-null-stalled-cycles-per-insn-metric.patch
Patch42:        perf-bench-futex-wake-restore-thread-count-default-to-online-cpu-count.patch
Patch43:        perf-map-fix-off-by-one-in-strncpy-size-argument.patch
Patch44:        perf-vendor-events-s390-add-new-deflate-counters-for-ibm-z15.patch
Patch45:        perf-record-fix-binding-of-aio-user-space-buffers-to-nodes.patch
Patch46:        perf-report-fix-no-branch-type-statistics-report-issue.patch
Patch47:        perf-cpumap-fix-snprintf-overflow-check.patch
# non upstream patches

Requires:       kernel >= 2.6.31
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a userspace tool 'perf', which monitors performance for
either unmodified binaries or the entire system. It requires a Linux kernel
which includes the Performance Counters for Linux (PCL) subsystem (>= 2.6.31).
This subsystem utilizes the Performance Monitoring Unit (PMU) / hardware
counters of the underlying cpu architecture (if supported).

%prep
# copy necessary files from kernel-source since we need to modify them
(cd /usr/src/linux ; tar -cf - COPYING CREDITS README tools include scripts Kbuild Makefile arch/*/{include,lib,Makefile} lib) | tar -xf - 
chmod +x tools/perf/util/generate-cmdlist.sh

%autopatch -p1

# don't error out on deprecated definitions in gtk2.h
sed -i 's@ignored "-Wstrict-prototypes"@&\n#pragma GCC diagnostic ignored "-Wdeprecated-declarations"@' tools/build/feature/test-gtk2.c

%build
cd tools/perf
export WERROR=0
# PASS rpm optflags as EXTRA_FLAGS,  passing as CFLAGS overrides and breaks build
make %{?_smp_mflags} -f Makefile.perf PYTHON=python3 EXTRA_CFLAGS="%{optflags}" ASCIIDOC8=1 prefix=/usr libdir=%{_libdir} perfexecdir=lib/%{name}-core all doc %{_perf_unwind} tipdir=share/doc/packages/perf

%install
cd tools/perf
export WERROR=0
make -f Makefile.perf V=1 PYTHON=python3 EXTRA_CFLAGS="%{optflags}" prefix=/usr libdir=%{_libdir} perfexecdir=lib/%{name}-core DESTDIR=%{buildroot} install install-doc %{_perf_unwind} tipdir=share/doc/packages/perf
mkdir -p %{buildroot}/%{_docdir}/perf/examples/bpf
mv %{buildroot}/usr/lib/perf/include/bpf/* %{buildroot}/%{_docdir}/perf/examples/bpf
mv %{buildroot}/usr/lib/perf/examples/bpf/* %{buildroot}/%{_docdir}/perf/examples/bpf

%files
%defattr(-, root, root)
%attr(0644, root, root) %doc COPYING CREDITS README tools/perf/design.txt
%if 0%{?suse_version} > 1315
%attr(0644, root, root) %doc %{_docdir}/perf/tips.txt
%endif
%{_bindir}/perf
%{_bindir}/trace
%{_libdir}/libperf-gtk.so
%ifnarch armv7l
%dir %{_libdir}/traceevent
%dir %{_libdir}/traceevent/plugins
%{_libdir}/traceevent/plugins/plugin_*.so
%endif
%attr(0644, -, -) %{_sysconfdir}/bash_completion.d/perf
%{_libexecdir}/%{name}-core
%{_datarootdir}/%{name}-core
%{_mandir}/man1/perf*
%dir %{_docdir}/perf
%dir %{_docdir}/perf/examples
%dir %{_docdir}/perf/examples/bpf
%{_docdir}/perf/examples/bpf/*

%changelog
* Fri May 29 2020 Tony Jones <tonyj@suse.com>
- Add support for new IBM S390 z15 deflate counters (bsc#1169763)
  New patch: perf-vendor-events-s390-add-new-deflate-counters-for-ibm-z15.patch
  New patch: perf-vendor-events-s390-use-s390-machine-name-instead-of-type-8561.patch
* Thu May 21 2020 Tony Jones <tonyj@suse.com>
- Add latest git-fixes
  * Fix snprintf overflow check
  * Fix off by one in strncpy() size argument
  * Fix binding of AIO user space buffers to nodes
  * Fix no branch type statistics report issue
  New patch: perf-cpumap-fix-snprintf-overflow-check.patch
  New patch: perf-map-fix-off-by-one-in-strncpy-size-argument.patch
  New patch: perf-record-fix-binding-of-aio-user-space-buffers-to-nodes.patch
  New patch: perf-report-fix-no-branch-type-statistics-report-issue.patch
* Fri Mar 27 2020 Tony Jones <tonyj@suse.com>
- Add latest git-fixes
  * perf bench futex-wake: Restore thread count default to online CPU
  * perf c2c: Display proper cpu count in nodes column
  * perf c2c: Fix report with offline cpus
  * perf callchain: Fix segfault in thread__resolve_callchain_sample()
  * perf diff: Use llabs() with 64-bit values
  * perf hists browser: Restore ESC as "Zoom out" of DSO/thread/etc
  * perf hists: Fix variable name's inconsistency in hists__for_each()
  * perf jevents: Fix resource leak in process_mapfile() and main()
  * perf list: Allow plurals for metric, metricgroup
  * perf map: No need to adjust the long name of modules
  * perf probe: Filter out instances except for inlined subroutine and
  * perf probe: Fix to find range-only function instance
  * perf probe: Fix to list probe event with correct line number
  * perf probe: Fix to probe a function which has no entry pc
  * perf probe: Fix to probe an inline function which has no entry pc
  * perf probe: Fix to show calling lines of inlined functions
  * perf probe: Fix to show function entry line as probe-able
  * perf probe: Fix to show inlined function callsite without entry_pc
  * perf probe: Fix to show ranges of variables in functions without
  * perf probe: Fix wrong address verification
  * perf probe: Skip end-of-sequence and non statement lines
  * perf probe: Skip overlapped location on searching variables
  * perf probe: Walk function lines in lexical blocks
  * perf regs: Make perf_reg_name() return "unknown" instead of NULL
  * perf report: Fix incorrectly added dimensions as switch perf data file
  * perf script: Allow --time with --reltime
  * perf script: Fix brstackinsn for AUXTRACE
  * perf stat: Don't report a null stalled cycles per insn metric
  * perf test: Report failure for mmap events
  * perf tests: Fix out of bounds memory access
  * perf ui gtk: Add missing zalloc object
  * perf vendor events amd: Remove redundant '['
  * perf vendor events arm64: Fix Hisi hip08 DDRC PMU eventname
  * perf vendor events: Remove P8 HW events which are not supported
  * perf vendor events s390: Add JSON transaction for machine type 8561
  * perf vendor events s390: Remove name from L1D_RO_EXCL_WRITES
  New patch: perf-bench-futex-wake-restore-thread-count-default-to-online-cpu-count.patch
  New patch: perf-c2c-display-proper-cpu-count-in-nodes-column.patch
  New patch: perf-c2c-fix-report-with-offline-cpus.patch
  New patch: perf-callchain-fix-segfault-in-thread__resolve_callchain_sample.patch
  New patch: perf-diff-use-llabs-with-64-bit-values.patch
  New patch: perf-hists-browser-restore-esc-as-zoom-out-of-dso-thread-etc.patch
  New patch: perf-hists-fix-variable-name-s-inconsistency-in-hists__for_each-macro.patch
  New patch: perf-jevents-fix-resource-leak-in-process_mapfile-and-main.patch
  New patch: perf-list-allow-plurals-for-metric-metricgroup.patch
  New patch: perf-map-no-need-to-adjust-the-long-name-of-modules.patch
  New patch: perf-probe-filter-out-instances-except-for-inlined-subroutine-and-subprogram.patch
  New patch: perf-probe-fix-to-find-range-only-function-instance.patch
  New patch: perf-probe-fix-to-list-probe-event-with-correct-line-number.patch
  New patch: perf-probe-fix-to-probe-a-function-which-has-no-entry-pc.patch
  New patch: perf-probe-fix-to-probe-an-inline-function-which-has-no-entry-pc.patch
  New patch: perf-probe-fix-to-show-calling-lines-of-inlined-functions.patch
  New patch: perf-probe-fix-to-show-function-entry-line-as-probe-able.patch
  New patch: perf-probe-fix-to-show-inlined-function-callsite-without-entry_pc.patch
  New patch: perf-probe-fix-to-show-ranges-of-variables-in-functions-without-entry_pc.patch
  New patch: perf-probe-fix-wrong-address-verification.patch
  New patch: perf-probe-skip-end-of-sequence-and-non-statement-lines.patch
  New patch: perf-probe-skip-overlapped-location-on-searching-variables.patch
  New patch: perf-probe-walk-function-lines-in-lexical-blocks.patch
  New patch: perf-regs-make-perf_reg_name-return-unknown-instead-of-null.patch
  New patch: perf-report-fix-incorrectly-added-dimensions-as-switch-perf-data-file.patch
  New patch: perf-script-allow-time-with-reltime.patch
  New patch: perf-script-fix-brstackinsn-for-auxtrace.patch
  New patch: perf-stat-don-t-report-a-null-stalled-cycles-per-insn-metric.patch
  New patch: perf-test-report-failure-for-mmap-events.patch
  New patch: perf-tests-fix-out-of-bounds-memory-access.patch
  New patch: perf-ui-gtk-add-missing-zalloc-object.patch
  New patch: perf-vendor-events-amd-remove-redundant.patch
  New patch: perf-vendor-events-arm64-fix-hisi-hip08-ddrc-pmu-eventname.patch
  New patch: perf-vendor-events-remove-p8-hw-events-which-are-not-supported.patch
  New patch: perf-vendor-events-s390-add-json-transaction-for-machine-type-8561.patch
  New patch: perf-vendor-events-s390-remove-name-from-l1d_ro_excl_writes-description.patch
* Mon Nov 25 2019 Tony Jones <tonyj@suse.com>
- Provide PEBS data via Intel PT trace logs (JIRA#SLE-9874)
  New patch: perf-tools-add-aux_output-attribute-flag.patch
  New patch: perf-tools-add-itrace-option-o-to-synthesize-aux-output-events.patch
  New patch: perf-intel-pt-process-options-for-pebs-event-synthesis.patch
  New patch: perf-tools-add-aux-output-config-term.patch
  New patch: perf-intel-pt-add-brief-documentation-for-pebs-via-intel-pt.patch
* Mon Nov 18 2019 Tony Jones <tonyj@suse.com>
- fix gtk2 detection (based on Factory change by iri Slaby <jslaby@suse.com>)
* Thu Aug  8 2019 Tony Jones <tonyj@suse.com>
- Fork for SP2 (v5.3 kernel source)
  Delete patch: perf-annotate-browser-display-titles-in-left-frame.patch
  Delete patch: perf-annotate-do-not-overwrite-sample-period.patch
  Delete patch: perf-annotate-document-show-total-period-option.patch
  Delete patch: perf-annotate-fix-storing-per-line-sym_hist_entry.patch
  Delete patch: perf-annotate-introduce-struct-sym_hist_entry.patch
  Delete patch: perf-annotate-rename-sum-to-nr_samples-in-struct-sym_hist.patch
  Delete patch: perf-annotate-stdio-fix-column-header-when-using-show-total-period.patch
  Delete patch: perf-annotate-stdio-fix-show-total-period.patch
  Delete patch: perf-annotate-stdio-set-enough-columns-for-show-total-period.patch
  Delete patch: perf-annotate-stdio-support-show-nr-samples-option.patch
  Delete patch: perf-annotate-store-the-sample-period-in-each-histogram-bucket.patch
  Delete patch: perf-annotate-tui-clarify-calculation-of-column-header-widths.patch
  Delete patch: perf-annotate-tui-fix-column-header-when-toggling-period-percent.patch
  Delete patch: perf-annotate-tui-fix-show-total-period.patch
  Delete patch: perf-annotate-tui-set-appropriate-column-width-for-period-percent.patch
  Delete patch: perf-annotate-tui-use-sym_hist_entry-in-disasm_line_samples.patch
  Delete patch: perf-arm-spe-Fix-uninitialized-record-error-variable.patch
  Delete patch: perf-arm64-Generate-system-call-table-from-asm-unist.patch
  Delete patch: perf-arm64-fix-generate-system-call-table-failed-with-tmp-mounted-with-noexec.patch
  Delete patch: perf-arm64-fix-include-path-for-asm-generic-unistd-h.patch
  Delete patch: perf-auxtrace-arm-Fixing-uninitialised-variable.patch
  Delete patch: perf-c2c-fix-c2c-report-for-empty-numa-node.patch
  Delete patch: perf-c2c-fix-spelling-mistakes-in-browser-help-text.patch
  Delete patch: perf-c2c-report-fix-crash-for-empty-browser.patch
  Delete patch: perf-events-parse-Remove-some-needless-local-variabl.patch
  Delete patch: perf-events-parse-Rename-parse_events_parse-argument.patch
  Delete patch: perf-events-parse-Rename-parsing-state-struct-to-cle.patch
  Delete patch: perf-events-parse-Use-just-one-parse-events-state-st.patch
  Delete patch: perf-evlist-remove-evlist-overwrite.patch
  Delete patch: perf-evlist-remove-overwrite-parameter-from-perf_evlist__mmap.patch
  Delete patch: perf-evlist-remove-overwrite-parameter-from-perf_evlist__mmap_ex.patch
  Delete patch: perf-evlist-remove-stale-mmap-read-for-backward.patch
  Delete patch: perf-evsel-add-read_counter.patch
  Delete patch: perf-evsel-add-verbose-output-for-sys_perf_event_open-fallback.patch
  Delete patch: perf-evsel-allow-asking-for-max-precise_ip-in-new_cycles.patch
  Delete patch: perf-evsel-expose-the-perf_missing_features-struct.patch
  Delete patch: perf-evsel-fix-attr-exclude_kernel-setting-for-default-cycles-p.patch
  Delete patch: perf-evsel-only-fall-back-group-read-for-leader.patch
  Delete patch: perf-evsel-set-attr-exclude_kernel-when-probing-max-attr-precise_ip.patch
  Delete patch: perf-ftrace-move-setup_pager-before-opening-trace_pipe.patch
  Delete patch: perf-header-add-struct-feat_fd-for-write.patch
  Delete patch: perf-header-encapsulate-read-and-swap.patch
  Delete patch: perf-header-fail-on-write_padded-error.patch
  Delete patch: perf-header-fix-wrong-node-write-in-numa_topology-feature.patch
  Delete patch: perf-header-remove-unused-cpu_nr-field-from-struct-cpu_topo.patch
  Delete patch: perf-header-revamp-do_write.patch
  Delete patch: perf-help-fix-a-bug-during-strstart-conversion.patch
  Delete patch: perf-hists-browser-add-parameter-to-disable-lost-event-warning.patch
  Delete patch: perf-hists-pass-perf_sample-to-_symbol__inc_addr_samples.patch
  Delete patch: perf-jevents-Make-build-fail-on-JSON-parse-error.patch
  Delete patch: perf-jevents-support-fcmask-and-portmask.patch
  Delete patch: perf-jvmti-fix-linker-error-when-libelf-config-is-disabled.patch
  Delete patch: perf-list-Add-metric-groups-to-perf-list.patch
  Delete patch: perf-mem-allow-all-record-report-options.patch
  Delete patch: perf-mem-c2c-fix-perf_mem_events-to-support-powerpc.patch
  Delete patch: perf-mem-document-a-missing-option.patch
  Delete patch: perf-mem-document-incorrect-and-missing-options.patch
  Delete patch: perf-mmap-add-new-return-value-logic-for-perf_mmap__read_init.patch
  Delete patch: perf-mmap-adopt-push-method-from-builtin-record-c.patch
  Delete patch: perf-mmap-be-consistent-when-checking-for-an-unmaped-ring-buffer.patch
  Delete patch: perf-mmap-cleanup-perf_mmap__push.patch
  Delete patch: perf-mmap-discard-legacy-interface-for-mmap-read.patch
  Delete patch: perf-mmap-discard-prev-in-perf_mmap__read.patch
  Delete patch: perf-mmap-don-t-discard-prev-in-backward-mode.patch
  Delete patch: perf-mmap-fix-accessing-unmapped-mmap-in-perf_mmap__read_done.patch
  Delete patch: perf-mmap-fix-perf-backward-recording.patch
  Delete patch: perf-mmap-introduce-perf_mmap__read_done.patch
  Delete patch: perf-mmap-introduce-perf_mmap__read_event.patch
  Delete patch: perf-mmap-introduce-perf_mmap__read_init.patch
  Delete patch: perf-mmap-move-perf_mmap-and-methods-to-separate-mmap-files.patch
  Delete patch: perf-mmap-recalculate-size-for-overwrite-mode.patch
  Delete patch: perf-mmap-remove-overwrite-and-check_messup-from-mmap-read.patch
  Delete patch: perf-mmap-remove-overwrite-from-arguments-list-of-perf_mmap__push.patch
  Delete patch: perf-pmu-Add-check-for-valid-cpuid-in-perf_pmu__find.patch
  Delete patch: perf-pmu-Pass-pmu-as-a-parameter-to-get_cpuid_str.patch
  Delete patch: perf-pmu-Unbreak-perf-record-for-arm-arm64-with-even.patch
  Delete patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  Delete patch: perf-probe-arm64-Fix-symbol-fixup-issues-due-to-ELF-.patch
  Delete patch: perf-probe-fix-kprobe-blacklist-checking-condition.patch
  Delete patch: perf-probe-support-sdt-markers-having-reference-counter-semaphore.patch
  Delete patch: perf-provide-definition-for-einval-on-32bit.patch
  Delete patch: perf-python-do-not-force-closing-original-perf-descriptor-in-evlist-get_pollfd.patch
  Delete patch: perf-python-make-clang_has_option-work-on-python-3.patch
  Delete patch: perf-python-make-twatch-py-work-with-both-python2-and-python3.patch
  Delete patch: perf-python-remove-mcet-and-fcf-protection-when-building-with-clang.patch
  Delete patch: perf-python-use-wno-redundant-decls-to-build-with-python-python3.patch
  Delete patch: perf-record-enable-arbitrary-event-names-thru-name-modifier.patch
  Delete patch: perf-record-make-record__mmap_read-generic.patch
  Delete patch: perf-report-extend-raw-dump-d-out-with-switch-out-event-type.patch
  Delete patch: perf-report-remove-unnecessary-check-in-annotate_browser_write.patch
  Delete patch: perf-script-add-missing-output-fields-in-a-hint.patch
  Delete patch: perf-script-add-support-to-display-sample-misc-field.patch
  Delete patch: perf-script-allow-adding-and-removing-fields.patch
  Delete patch: perf-script-extend-misc-field-decoding-with-switch-out-event-type.patch
  Delete patch: perf-script-fix-crash-when-processing-recorded-stat-data.patch
  Delete patch: perf-script-fix-crash-with-printing-mixed-trace-point-and-other-events.patch
  Delete patch: perf-script-python-add-perf_sample-dict-to-tracepoint-handlers.patch
  Delete patch: perf-script-python-add-printdate-function-to-sql-exporters.patch
  Delete patch: perf-script-python-add-python3-support-to-check-perf-trace-py.patch
  Delete patch: perf-script-python-add-python3-support-to-event_analyzing_sample-py.patch
  Delete patch: perf-script-python-add-python3-support-to-export-to-postgresql-py.patch
  Delete patch: perf-script-python-add-python3-support-to-exported-sql-viewer-py.patch
  Delete patch: perf-script-python-add-python3-support-to-failed-syscalls-by-pid-py.patch
  Delete patch: perf-script-python-add-python3-support-to-futex-contention-py.patch
  Delete patch: perf-script-python-add-python3-support-to-net_dropmonitor-py.patch
  Delete patch: perf-script-python-add-python3-support-to-netdev-times-py.patch
  Delete patch: perf-script-python-add-python3-support-to-sctop-py.patch
  Delete patch: perf-script-python-add-python3-support-to-stackcollapse-py.patch
  Delete patch: perf-script-python-add-python3-support-to-stat-cpi-py.patch
  Delete patch: perf-script-python-add-python3-support-to-syscall-counts-by-pid-py.patch
  Delete patch: perf-script-python-add-python3-support-to-syscall-counts-py.patch
  Delete patch: perf-script-python-add-python3-support-to-tests-attr-py.patch
  Delete patch: perf-script-python-add-sample_read-to-dict.patch
  Delete patch: perf-script-python-add-trace_context-extension-module-to-sys-modules.patch
  Delete patch: perf-script-python-allocate-memory-only-if-handler-exists.patch
  Delete patch: perf-script-python-refactor-creation-of-perf-sample-dict.patch
  Delete patch: perf-script-python-remove-explicit-shebang-from-python-scripts.patch
  Delete patch: perf-script-python-remove-explicit-shebang-from-setup-py.patch
  Delete patch: perf-script-python-remove-explicit-shebang-from-tests-attr-c.patch
  Delete patch: perf-script-python-remove-mixed-indentation.patch
  Delete patch: perf-script-python-use-pybytes-for-attr-in-trace-event-python.patch
  Delete patch: perf-script-show-hw-cache-events.patch
  Delete patch: perf-scripting-python-add-ppc64le-to-audit-uname-list.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-core-py.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-eventclass-py.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-sched-migration-py.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-schedgui-py.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-util-py.patch
  Delete patch: perf-scripts-python-fix-missing-call_path_id-in-export-to-postgresql-script.patch
  Delete patch: perf-stat-Factor-out-generic-metric-printing.patch
  Delete patch: perf-stat-Only-auto-merge-events-that-are-PMU-aliase.patch
  Delete patch: perf-stat-Support-JSON-metrics-in-perf-stat.patch
  Delete patch: perf-stat-enable-1ms-interval-for-printing-event-counters-values.patch
  Delete patch: perf-stat-use-group-read-for-event-groups.patch
  Delete patch: perf-symbols-Fix-plt-entry-calculation-for-ARM-and-A.patch
  Delete patch: perf-symbols-fix-memory-corruption-because-of-zero-length-symbols.patch
  Delete patch: perf-symbols-set-plt-entry-header-sizes-properly-on-sparc.patch
  Delete patch: perf-test-add-test-cases-for-new-data-source-encoding.patch
  Delete patch: perf-test-make-list-subcommand-match-main-perf-test-numbering-matching.patch
  Delete patch: perf-test-powerpc-fix-object-code-reading-test.patch
  Delete patch: perf-test-sdt-handle-realpath-failure.patch
  Delete patch: perf-test-update-mmap-read-functions-for-backward-ring-buffer-test.patch
  Delete patch: perf-tests-Run-dwarf-unwind-test-on-arm32.patch
  Delete patch: perf-tests-attr-fix-no-delay-test.patch
  Delete patch: perf-tests-set-evlist-of-test__backward_ring_buffer-to-overwrite.patch
  Delete patch: perf-tests-set-evlist-of-test__basic_mmap-to-overwrite.patch
  Delete patch: perf-tests-set-evlist-of-test__sw_clock_freq-to-overwrite.patch
  Delete patch: perf-tests-set-evlist-of-test__task_exit-to-overwrite.patch
  Delete patch: perf-tools-Add-ARM-Statistical-Profiling-Extensions-.patch
  Delete patch: perf-tools-add-cpu_topology-object.patch
  Delete patch: perf-tools-add-numa_topology-object.patch
  Delete patch: perf-tools-add-perf_evsel__read_size-function.patch
  Delete patch: perf-tools-add-python-3-support.patch
  Delete patch: perf-tools-add-support-for-printing-new-mem_info-encodings.patch
  Delete patch: perf-tools-arm64-Add-libdw-DWARF-post-unwind-support.patch
  Delete patch: perf-tools-arm64-Add-support-for-get_cpuid_str-funct.patch
  Delete patch: perf-tools-fix-python-extension-build-for-gcc-8.patch
  Delete patch: perf-tools-handle-topology-headers-with-no-cpu.patch
  Delete patch: perf-tools-really-install-manpages-via-make-install-man.patch
  Delete patch: perf-tools-rename-backward-to-overwrite-in-evlist-mmap-and-record.patch
  Delete patch: perf-top-add-overwrite-fall-back.patch
  Delete patch: perf-top-allow-disabling-the-overwrite-mode.patch
  Delete patch: perf-top-check-per-event-overwrite-term.patch
  Delete patch: perf-top-check-the-latency-of-perf_top__mmap_read.patch
  Delete patch: perf-top-do-not-use-overwrite-mode-by-default.patch
  Delete patch: perf-top-fix-annoying-fallback-message-on-older-kernels.patch
  Delete patch: perf-top-fix-window-dimensions-change-handling.patch
  Delete patch: perf-top-remove-lost-events-checking.patch
  Delete patch: perf-top-switch-default-mode-to-overwrite-mode.patch
  Delete patch: perf-trace-fix-off-by-one-string-allocation-problem.patch
  Delete patch: perf-util-add-const-modifier-to-buf-in-writen-function.patch
  Delete patch: perf-vendor-events-Add-support-for-arch-standard-eve.patch
  Delete patch: perf-vendor-events-Add-support-for-pmu-events-vendor.patch
  Delete patch: perf-vendor-events-Drop-incomplete-multiple-mapfile-.patch
  Delete patch: perf-vendor-events-Drop-support-for-unused-topic-dir.patch
  Delete patch: perf-vendor-events-Fix-error-code-in-json_events.patch
  Delete patch: perf-vendor-events-Support-metric_group-and-no-event.patch
  Delete patch: perf-vendor-events-aarch64-Add-JSON-metrics-for-ARM-.patch
  Delete patch: perf-vendor-events-add-core-event-list-for-skylake-server.patch
  Delete patch: perf-vendor-events-add-goldmont-plus-v1-event-file.patch
  Delete patch: perf-vendor-events-add-skylake-server-uncore-event-list.patch
  Delete patch: perf-vendor-events-arm64-Add-ThunderX2-implementatio.patch
  Delete patch: perf-vendor-events-arm64-Add-armv8-recommended.json.patch
  Delete patch: perf-vendor-events-arm64-Enable-JSON-events-for-Thun.patch
  Delete patch: perf-vendor-events-arm64-Enable-JSON-events-for-eMAG.patch
  Delete patch: perf-vendor-events-arm64-Fixup-ThunderX2-to-use-reco.patch
  Delete patch: perf-vendor-events-arm64-Relocate-Cortex-A53-JSONs-t.patch
  Delete patch: perf-vendor-events-arm64-Relocate-ThunderX2-JSON-to-.patch
  Delete patch: perf-vendor-events-arm64-Update-ThunderX2-implementa.patch
  Delete patch: perf-vendor-events-arm64-add-HiSilicon-hip08-JSON-fi.patch
  Delete patch: perf-vendor-events-arm64-fixup-A53-to-use-recommende.patch
  Delete patch: perf-vendor-events-update-power9-events-9749adc3.patch
  Delete patch: perf-vendor-events-update-power9-events-e795dd42.patch
  Delete patch: perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
  Delete patch: tools-include-Adopt-strstarts-from-the-kernel.patch
- Merge Factory change
  Tue Oct 16 22:51:15 UTC 2018 - Tony Jones <tonyj@suse.com>
  - Update examples paths to resolve build failures.
* Tue Jul 23 2019 Tony Jones <tonyj@suse.com>
- perf script: Fix crash printing mixed tracepoint/other events (bsc#1142104)
  New patch: perf-script-fix-crash-with-printing-mixed-trace-point-and-other-events.patch
* Thu Mar 28 2019 Tony Jones <tonyj@suse.com>
- Correct missing static qualifier in previous backport of
  perf-mmap-be-consistent-when-checking-for-an-unmaped-ring-buffer.patch
- Git-fixes:
  New patch: perf-python-do-not-force-closing-original-perf-descriptor-in-evlist-get_pollfd.patch
* Sat Mar 23 2019 Tony Jones <tonyj@suse.com>
- Handle empty node 0 topology for c2c (bsc#1127191)
  New patch: perf-header-encapsulate-read-and-swap.patch
  New patch: perf-util-add-const-modifier-to-buf-in-writen-function.patch
  New patch: perf-header-fail-on-write_padded-error.patch
  New patch: perf-header-revamp-do_write.patch
  New patch: perf-header-add-struct-feat_fd-for-write.patch
  New patch: perf-header-remove-unused-cpu_nr-field-from-struct-cpu_topo.patch
  New patch: perf-header-fix-wrong-node-write-in-numa_topology-feature.patch
  New patch: perf-tools-add-cpu_topology-object.patch
  New patch: perf-tools-add-numa_topology-object.patch
  New patch: perf-c2c-fix-c2c-report-for-empty-numa-node.patch
  New patch: perf-tools-handle-topology-headers-with-no-cpu.patch
  New patch: perf-c2c-fix-spelling-mistakes-in-browser-help-text.patch
  New patch: perf-c2c-report-fix-crash-for-empty-browser.patch
* Fri Mar 22 2019 Tony Jones <tonyj@suse.com>
- Refresh patches for previous Python3 (Thu Jan 10 23:23:28 UTC 2019)
  submission now that all patches are upstream
  Delete patch: port-netdev-times-script-to-python3.patch
  Delete patch: port-check-perf-trace-script-to-python3.patch
  Delete patch: port-event_analyzing_sample-script-to-python3.patch
  Delete patch: port-failed-syscalls-by-pid-script-to-python3.patch
  Delete patch: port-futex-contention-script-to-python3.patch
  Delete patch: port-net_dropmonitor-script-to-python3.patch
  Delete patch: port-sctop-script-to-python3.patch
  Delete patch: port-stackcollapse-script-to-python3.patch
  Delete patch: port-stat-cpi-script-to-python3.patch
  Delete patch: port-syscall-counts-by-pid-script-to-python3.patch
  Delete patch: port-python-syscall-counts-script-to-python3.patch
  Delete patch: remove-shebang-from-scripts-python.patch
  Delete patch: remove-shebang-from-tests-attr.py.patch
  Delete patch: remove-shebang-from-util-setup.py.patch
  Delete patch: update-tests-attr.py-to-support-python3.patch
  Delete patch: use-pybytes-for-attr-in-trace-event-python.patch
  New patch: perf-script-python-add-printdate-function-to-sql-exporters.patch
  New patch: perf-script-python-add-python3-support-to-export-to-postgresql-py.patch
  New patch: perf-script-python-add-python3-support-to-exported-sql-viewer-py.patch
  New patch: perf-script-python-add-python3-support-to-failed-syscalls-by-pid-py.patch
  New patch: perf-script-python-add-python3-support-to-futex-contention-py.patch  New patch: perf-script-python-add-python3-support-to-net_dropmonitor-py.patch
  New patch: perf-script-python-add-python3-support-to-netdev-times-py.patch
  New patch: perf-script-python-add-python3-support-to-sctop-py.patch
  New patch: perf-script-python-add-python3-support-to-stackcollapse-py.patch
  New patch: perf-script-python-add-python3-support-to-stat-cpi-py.patch
  New patch: perf-script-python-add-python3-support-to-syscall-counts-by-pid-py.patch
  New patch: perf-script-python-add-python3-support-to-syscall-counts-py.patch
  New patch: perf-script-python-add-python3-support-to-tests-attr-py.patch
  New patch: perf-script-python-add-trace_context-extension-module-to-sys-modules.patch
  New patch: perf-script-python-remove-explicit-shebang-from-python-scripts.patch
  New patch: perf-script-python-remove-explicit-shebang-from-setup-py.patch
  New patch: perf-script-python-remove-explicit-shebang-from-tests-attr-c.patch
  New patch: perf-script-python-remove-mixed-indentation.patch
  New patch: perf-script-python-add-python3-support-to-check-perf-trace-py.patch
  New patch: perf-script-python-add-python3-support-to-event_analyzing_sample-py.patch
  New patch: perf-script-python-use-pybytes-for-attr-in-trace-event-python.patch
* Fri Mar 22 2019 Tony Jones <tonyj@suse.com>
- Fix crash when processing recorded stat data
  New patch: perf-script-fix-crash-when-processing-recorded-stat-data.patch
* Wed Feb 13 2019 tonyj@suse.com
- Add POWER mem/c2c support (FATE#326866, bsc#1124370)
  New patch: perf-mem-c2c-fix-perf_mem_events-to-support-powerpc.patch
  New patch: perf-mem-allow-all-record-report-options.patch
  New patch: perf-mem-document-a-missing-option.patch
  New patch: perf-mem-document-incorrect-and-missing-options.patch
* Fri Feb  1 2019 Tony Jones <tonyj@suse.com>
- Uprobes: Support for SDT events with reference counter
  (FATE#326782, bsc#1115391)
  New patch: perf-probe-support-sdt-markers-having-reference-counter-semaphore.patch
* Mon Jan 14 2019 Tony Jones <tonyj@suse.com>
- Add support for VTune (FATE#326324)
  New patch:  perf-record-enable-arbitrary-event-names-thru-name-modifier.patch
  New patch:  perf-report-extend-raw-dump-d-out-with-switch-out-event-type.patch
  New patch:  perf-script-add-missing-output-fields-in-a-hint.patch
  New patch:  perf-script-add-support-to-display-sample-misc-field.patch
  New patch:  perf-script-allow-adding-and-removing-fields.patch
  New patch:  perf-script-extend-misc-field-decoding-with-switch-out-event-type.patch
  New patch:  perf-stat-enable-1ms-interval-for-printing-event-counters-values.patch
* Thu Jan 10 2019 Tony Jones <tonyj@suse.com>
- Enable python3.  Remove all uses of python2 (bsc#1082197)
  New patch: perf-script-python-allocate-memory-only-if-handler-exists.patch
  New patch: perf-script-python-refactor-creation-of-perf-sample-dict.patch
  New patch: perf-script-python-add-sample_read-to-dict.patch
  New patch: perf-script-python-add-perf_sample-dict-to-tracepoint-handlers.patch
  New patch: perf-python-make-twatch-py-work-with-both-python2-and-python3.patch
  New patch: perf-tools-add-python-3-support.patch
  New patch: perf-tools-fix-python-extension-build-for-gcc-8.patch
  New patch: perf-scripts-python-add-python-3-support-to-util-py.patch
  New patch: perf-scripts-python-add-python-3-support-to-sched-migration-py.patch
  New patch: perf-scripts-python-add-python-3-support-to-schedgui-py.patch
  New patch: perf-scripts-python-add-python-3-support-to-eventclass-py.patch
  New patch: perf-scripts-python-add-python-3-support-to-core-py.patch
  New patch: perf-python-remove-mcet-and-fcf-protection-when-building-with-clang.patch
  New patch: perf-python-use-wno-redundant-decls-to-build-with-python-python3.patch
  New patch: perf-python-make-clang_has_option-work-on-python-3.patch
  New patch: update-tests-attr.py-to-support-python3.patch
  New patch: remove-shebang-from-util-setup.py.patch
  New patch: remove-shebang-from-tests-attr.py.patch
  New patch: remove-shebang-from-scripts-python.patch
  New patch: add-trace_context-extension-module-to-sys-modules.patch
  New patch: use-pybytes-for-attr-in-trace-event-python.patch
  New patch: port-netdev-times-script-to-python3.patch
  New patch: port-check-perf-trace-script-to-python3.patch
  New patch: port-event_analyzing_sample-script-to-python3.patch
  New patch: port-failed-syscalls-by-pid-script-to-python3.patch
  New patch: port-futex-contention-script-to-python3.patch
  New patch: port-net_dropmonitor-script-to-python3.patch
  New patch: port-sctop-script-to-python3.patch
  New patch: port-stackcollapse-script-to-python3.patch
  New patch: port-stat-cpi-script-to-python3.patch
  New patch: port-syscall-counts-by-pid-script-to-python3.patch
  New patch: port-python-syscall-counts-script-to-python3.patch
  New patch: port-sql-scripts-to-python3.patch
* Tue Nov 13 2018 Tony Jones <tonyj@suse.com>
- Add support for ARMv8.x-A statistical profiling extension (FATE#325865)
- Add support for ARMv8.1-PMU: ARMv8.1 PMU Extensions (FATE#325861)
  New patch: perf-arm64-Generate-system-call-table-from-asm-unist.patch
  New patch: perf-arm-spe-Fix-uninitialized-record-error-variable.patch
  New patch: perf-auxtrace-arm-Fixing-uninitialised-variable.patch
  New patch: perf-events-parse-Remove-some-needless-local-variabl.patch
  New patch: perf-events-parse-Rename-parse_events_parse-argument.patch
  New patch: perf-events-parse-Rename-parsing-state-struct-to-cle.patch
  New patch: perf-events-parse-Use-just-one-parse-events-state-st.patch
  New patch: perf-help-fix-a-bug-during-strstart-conversion.patch
  New patch: perf-list-Add-metric-groups-to-perf-list.patch
  New patch: perf-pmu-Add-check-for-valid-cpuid-in-perf_pmu__find.patch
  New patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  New patch: perf-pmu-Pass-pmu-as-a-parameter-to-get_cpuid_str.patch
  New patch: perf-pmu-Unbreak-perf-record-for-arm-arm64-with-even.patch
  New patch: perf-probe-arm64-Fix-symbol-fixup-issues-due-to-ELF-.patch
  New patch: perf-stat-Factor-out-generic-metric-printing.patch
  New patch: perf-stat-Only-auto-merge-events-that-are-PMU-aliase.patch
  New patch: perf-stat-Support-JSON-metrics-in-perf-stat.patch
  New patch: perf-symbols-Fix-plt-entry-calculation-for-ARM-and-A.patch
  New patch: perf-tests-Run-dwarf-unwind-test-on-arm32.patch
  New patch: perf-tools-Add-ARM-Statistical-Profiling-Extensions-.patch
  New patch: perf-tools-arm64-Add-libdw-DWARF-post-unwind-support.patch
  New patch: perf-tools-arm64-Add-support-for-get_cpuid_str-funct.patch
  New patch: perf-vendor-events-arm64-Enable-JSON-events-for-eMAG.patch
  New patch: perf-vendor-events-arm64-Update-ThunderX2-implementa.patch
  New patch: tools-include-Adopt-strstarts-from-the-kernel.patch
- Incorporate git-fixes for FATE#325865/FATE#325861
  New patch: perf-arm64-fix-generate-system-call-table-failed-with-tmp-mounted-with-noexec.patch
  New patch: perf-arm64-fix-include-path-for-asm-generic-unistd-h.patch missing
  New patch: perf-symbols-set-plt-entry-header-sizes-properly-on-sparc.patch missing
- Add Hi1620 Perf hardware enablement (FATE#326417)
  New patch: perf-jevents-Make-build-fail-on-JSON-parse-error.patch
  New patch: perf-vendor-events-aarch64-Add-JSON-metrics-for-ARM-.patch
  New patch: perf-vendor-events-Add-support-for-arch-standard-eve.patch
  New patch: perf-vendor-events-Add-support-for-pmu-events-vendor.patch
  New patch: perf-vendor-events-arm64-Add-armv8-recommended.json.patch
  New patch: perf-vendor-events-arm64-add-HiSilicon-hip08-JSON-fi.patch
  New patch: perf-vendor-events-arm64-Add-ThunderX2-implementatio.patch
  New patch: perf-vendor-events-arm64-Enable-JSON-events-for-Thun.patch
  New patch: perf-vendor-events-arm64-fixup-A53-to-use-recommende.patch
  New patch: perf-vendor-events-arm64-Fixup-ThunderX2-to-use-reco.patch
  New patch: perf-vendor-events-arm64-Relocate-Cortex-A53-JSONs-t.patch
  New patch: perf-vendor-events-arm64-Relocate-ThunderX2-JSON-to-.patch
  New patch: perf-vendor-events-Drop-incomplete-multiple-mapfile-.patch
  New patch: perf-vendor-events-Drop-support-for-unused-topic-dir.patch
  New patch: perf-vendor-events-Fix-error-code-in-json_events.patch
  New patch: perf-vendor-events-Support-metric_group-and-no-event.patch
* Tue Nov  6 2018 Tony Jones <tonyj@suse.com>
- Add warning to perf top for too slow CPUs (FATE#325579)
  New patch: perf-evlist-remove-evlist-overwrite.patch
  New patch: perf-evlist-remove-overwrite-parameter-from-perf_evlist__mmap.patch
  New patch: perf-evlist-remove-overwrite-parameter-from-perf_evlist__mmap_ex.patch
  New patch: perf-evlist-remove-stale-mmap-read-for-backward.patch
  New patch: perf-evsel-add-read_counter.patch
  New patch: perf-evsel-add-verbose-output-for-sys_perf_event_open-fallback.patch
  New patch: perf-evsel-expose-the-perf_missing_features-struct.patch
  New patch: perf-hists-browser-add-parameter-to-disable-lost-event-warning.patch
  New patch: perf-mmap-add-new-return-value-logic-for-perf_mmap__read_init.patch
  New patch: perf-mmap-adopt-push-method-from-builtin-record-c.patch
  New patch: perf-mmap-cleanup-perf_mmap__push.patch
  New patch: perf-mmap-discard-legacy-interface-for-mmap-read.patch
  New patch: perf-mmap-discard-prev-in-perf_mmap__read.patch
  New patch: perf-mmap-don-t-discard-prev-in-backward-mode.patch
  New patch: perf-mmap-fix-perf-backward-recording.patch
  New patch: perf-mmap-introduce-perf_mmap__read_done.patch
  New patch: perf-mmap-introduce-perf_mmap__read_event.patch
  New patch: perf-mmap-introduce-perf_mmap__read_init.patch
  New patch: perf-mmap-move-perf_mmap-and-methods-to-separate-mmap-files.patch
  New patch: perf-mmap-recalculate-size-for-overwrite-mode.patch
  New patch: perf-mmap-remove-overwrite-and-check_messup-from-mmap-read.patch
  New patch: perf-mmap-remove-overwrite-from-arguments-list-of-perf_mmap__push.patch
  New patch: perf-record-make-record__mmap_read-generic.patch
  New patch: perf-stat-use-group-read-for-event-groups.patch
  New patch: perf-test-update-mmap-read-functions-for-backward-ring-buffer-test.patch
  New patch: perf-tests-set-evlist-of-test__backward_ring_buffer-to-overwrite.patch
  New patch: perf-tests-set-evlist-of-test__basic_mmap-to-overwrite.patch
  New patch: perf-tests-set-evlist-of-test__sw_clock_freq-to-overwrite.patch
  New patch: perf-tests-set-evlist-of-test__task_exit-to-overwrite.patch
  New patch: perf-tools-add-perf_evsel__read_size-function.patch
  New patch: perf-tools-rename-backward-to-overwrite-in-evlist-mmap-and-record.patch
  New patch: perf-top-add-overwrite-fall-back.patch
  New patch: perf-top-check-per-event-overwrite-term.patch
  New patch: perf-top-check-the-latency-of-perf_top__mmap_read.patch
  New patch: perf-top-fix-window-dimensions-change-handling.patch
  New patch: perf-top-remove-lost-events-checking.patch
  New patch: perf-top-switch-default-mode-to-overwrite-mode.patch
  o
- Incorporate git-fixes for FATE#325579
  New patch: perf-mmap-be-consistent-when-checking-for-an-unmaped-ring-buffer.patch
  New patch: perf-mmap-fix-accessing-unmapped-mmap-in-perf_mmap__read_done.patch
  New patch: perf-top-allow-disabling-the-overwrite-mode.patch
  New patch: perf-top-do-not-use-overwrite-mode-by-default.patch
  New patch: perf-top-fix-annoying-fallback-message-on-older-kernels.patch
  New patch: perf-evsel-only-fall-back-group-read-for-leader.patch
* Mon Aug 27 2018 tonyj@suse.com
- libebl ppc64 dependancy was inadvertantly dropped, regression from
  "Thu Jun 15 22:27:56 - Add ppc64 requires on libebl (bsc#1040770)".
  Re-add dependancy (bsc#1106048)
* Wed Aug  1 2018 tonyj@suse.com
- Support crystall ridge / far / near memory indication in PEBS (FATE#325127)
  New patch: perf-test-add-test-cases-for-new-data-source-encoding.patch
  New patch: perf-tools-add-support-for-printing-new-mem_info-encodings.patch
* Wed Aug  1 2018 tonyj@suse.com
- PMU events are not listed because pvr code is missing for POWER9 (bsc#1075525 )
  New patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  New patch: perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
* Fri Jul 27 2018 tonyj@suse.com
- Merge missing changes from SLE12-SP3 branch
  Thu Jan 18 01:12:14 UTC 2018 - tonyj@suse.com
  - Add necessary power pvr support (bsc#1075525)
    New patch: perf-pmu-events-support-additional-power8-pvr-in-mapfile.patch
    New patch: perf-vendor-events-add-power9-pmu-events.patch
    New patch: perf-vendor-events-add-power9-pvrs-to-mapfile.patch
    New patch: perf-vendor-events-powerpc-remove-suffix-in-mapfile.patch
    New patch: perf-vendor-events-update-power9-events-3c22ba52.patch
    New patch: perf-vendor-events-powerpc-remove-duplicate-events.patch
  Wed Dec  6 19:53:35 UTC 2017 - tonyj@suse.com
  - Add perf scripting support for ppc64le (bsc#1056756)
    New patch: perf-scripting-python-add-ppc64le-to-audit-uname
* Fri Jul 27 2018 tonyj@suse.com
- Resequence patches into Patch-mainline order
- Rename power event patches for consistency and to avoid exportpatch
  name clashes
  perf-vendor-events-update-power9-events.patch ->
    perf-vendor-events-update-power9-events-9749adc3.patch
  perf-vendor-events-powerpc-update-power9-events.patch ->
    perf-vendor-events-update-power9-events-e795dd42.patch
* Wed Jul 25 2018 tonyj@suse.com
- Initial checkin for SLE12-SP4.  Rebase off SLE15.
- Add JSON perf event lists for GLP (FATE#325092)
  new patch: perf-vendor-events-add-goldmont-plus-v1-event-file.patch
- Support perf core/uncore event list for Skylake server (FATE#325122)
  new patch: perf-vendor-events-add-core-event-list-for-skylake-server.patch
  new patch: perf-vendor-events-add-skylake-server-uncore-event-list.patch
  new patch: perf-jevents-support-fcmask-and-portmask.patch
* Tue Jun 12 2018 tonyj@suse.com
- perf script: Show hw-cache events (bsc#1096885)
  new patch: perf-script-show-hw-cache-events.patch
* Mon Apr  9 2018 tonyj@suse.com
- More Power9 event updates (bsc#1056686)
  New patch: perf-vendor-events-update-power9-events.patch
* Tue Apr  3 2018 tonyj@suse.com
- Add libpython support, regression from SLE12 (bsc#1082197)
* Fri Mar  9 2018 tonyj@suse.com
- Fix attr.exclude_kernel setting for default cycles:p (bsc#1083691)
  Regression from commit Mon Nov 27 23:45:48 UTC 2017
  New patch: perf-evsel-fix-attr-exclude_kernel-setting-for-default-cycles-p.patch
  New patch (dependent): perf-evsel-allow-asking-for-max-precise_ip-in-new_cycles.patch
- Git-fixes change (bsc#1070010)
  Fixes: perf-annotate-fix-storing-per-line-sym_hist_entry.patch (Mon Nov 27)
  New patch: perf-annotate-fix-storing-per-line-sym_hist_entry.patch
* Thu Feb 22 2018 tonyj@suse.com
- perf vendor events: Use more flexible pattern matching for CPU
  identification for mapfile.csv (bsc#1081960)
  New patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  New patch: perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
* Thu Jan 18 2018 tonyj@suse.com
- powerpc: fix 'Object code reading' test (bsc#1073195)
  New patch: perf-test-powerpc-fix-object-code-reading-test.patch
* Mon Nov 27 2017 tonyj@suse.com
- Update power9 events (bsc#1069737)
  New patch: perf-vendor-events-powerpc-update-power9-events.patch
- Memory corruption due to zero length symbols (bsc#1068222)
  New patch: perf-symbols-fix-memory-corruption-because-of-zero-length-symbols.patc
- Incorporate fixes identified by git-fixes and their dependencies (bsc#1070010)
  New patch: perf-annotate-browser-display-titles-in-left-frame.patch
  New patch: perf-annotate-document-show-total-period-option.patch
  New patch: perf-annotate-do-not-overwrite-sample-period.patch
  New patch: perf-annotate-introduce-struct-sym_hist_entry.patch
  New patch: perf-annotate-rename-sum-to-nr_samples-in-struct-sym_hist.patch
  New patch: perf-annotate-stdio-fix-column-header-when-using-show-total-period.patch
  New patch: perf-annotate-stdio-fix-show-total-period.patch
  New patch: perf-annotate-stdio-set-enough-columns-for-show-total-period.patch
  New patch: perf-annotate-stdio-support-show-nr-samples-option.patch
  New patch: perf-annotate-store-the-sample-period-in-each-histogram-bucket.patch
  New patch: perf-annotate-tui-clarify-calculation-of-column-header-widths.patch  New patch: perf-annotate-tui-fix-column-header-when-toggling-period-percent.patch
  New patch: perf-annotate-tui-fix-show-total-period.patch
  New patch: perf-annotate-tui-set-appropriate-column-width-for-period-percent.patch
  New patch: perf-annotate-tui-use-sym_hist_entry-in-disasm_line_samples.patch
  New patch: perf-evsel-set-attr-exclude_kernel-when-probing-max-attr-precise_ip.patch
  New patch: perf-ftrace-move-setup_pager-before-opening-trace_pipe.patch
  New patch: perf-hists-pass-perf_sample-to-_symbol__inc_addr_samples.patch
  New patch: perf-jvmti-fix-linker-error-when-libelf-config-is-disabled.patch
  New patch: perf-probe-fix-kprobe-blacklist-checking-condition.patch
  New patch: perf-report-remove-unnecessary-check-in-annotate_browser_write.patch
  New patch: perf-scripts-python-fix-missing-call_path_id-in-export-to-postgresql-script.patch
  New patch: perf-test-make-list-subcommand-match-main-perf-test-numbering-matching.patch
  New patch: perf-tests-attr-fix-no-delay-test.patch
  New patch: perf-test-sdt-handle-realpath-failure.patch
  New patch: perf-tools-really-install-manpages-via-make-install-man.patch
  New patch: perf-trace-fix-off-by-one-string-allocation-problem.patch
* Fri Sep 15 2017 tonyj@suse.com
- Fix x86 32bit build error
  New patch: perf-provide-definition-for-einval-on-32bit.patch
* Thu Sep  1 2016 tonyj@suse.com
- Fix build error (tips.txt) on Leap42.2
- Fix doc file attributes
* Mon Jun  6 2016 jslaby@suse.com
- disable Werror completely. It breaks build due to shadow variables
  in external (perl) headers.
- add %%{?_smp_mflags}
* Mon Apr  4 2016 tonyj@suse.com
- Package perf-tips as docs.
- Include support for xz compressed images
* Mon Jan 11 2016 tonyj@suse.com
- Support strace/data.
* Sun Oct 11 2015 dmueller@suse.com
- enable numa support for aarch64
* Thu Jul 16 2015 antoine.belvire@laposte.net
- Remove perf-fix-branch-stack-mode-cannot-be-set.patch (upstreamed).
* Sun Jun 28 2015 antoine.belvire@laposte.net
- Fix build with GCC 5
  * perf-fix-branch-stack-mode-cannot-be-set.patch
* Wed May 13 2015 tonyj@suse.com
- Fix ppc64/ppc64le breakage due to libexecdir/libdir
* Mon Mar  9 2015 dimstar@opensuse.org
- Inject libdir=%%{_libdir} into make calls.
* Thu Jan  8 2015 dimstar@opensuse.org
- Remove build hack for kernel not building against glibc 2.20.
* Thu Nov 27 2014 dimstar@opensuse.org
- Build hack: if util/util.h does not (yet) define _DEFAULT_SOURCE,
  we export WERROR=0, which removes -Werror from CFLAGS. Once a
  kernel lands that defines _DEFAULT_SOURCE, we fail the build in
  to remove this hack, making it a (hopefully_ short-livinging one.
* Fri Jun 27 2014 tonyj@suse.com
- Build for s390[x] without libunwind (bnc#882855)
* Tue Mar 25 2014 aj@ajaissle.de
- Fix current build including 'trace event' plugins
- Do not include 'trace event' plugins when on armv7l
- BuildRequire libnuma-devel to enable 'perf bench numa mem', but
  only require if we build for ia64 x86_64 ppc64 ppc64le  ppc %%sparc
- Spec cleanup:
  * Add Url: https://perf.wiki.kernel.org/
  * Drop %%clean-section: We don't need to cleanup the buildroot
  * bash_completion.d/perf doesn't need executable bit
* Fri Jan 24 2014 tonyj@suse.com
- Fix build errors (invoke Makefile.perf directly to pass perfexecdir)
- Add /usr/bin/trace alias for perf (mainline b52bc234)
- Add libperf-gtk.so (loaded via dlsym, mainline fc67297b)
* Wed Dec  4 2013 tonyj@suse.com
- Drop patch perl-5.18-nowarn.patch (mainline)
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Wed Aug 21 2013 tonyj@suse.com
- Resolve build errors
- Drop patch perf-tests-ppc64-fix-compile-errors.patch (mainline)
- Refresh patch perl-5.18-nowarn.patch
* Wed Jul 10 2013 tonyj@suse.com
- Add patch 'perf-tests-ppc64-fix-compile-errors.patch' to resolve
  openSUSE:Factory:PowerPC testsuite build errors
* Tue Jul  9 2013 tonyj@suse.com
- Add audit-devel, gtk2-devel and libunwind-devel to support optional
  functionality.
- Add 'perl-5.18-nowarn.patch' to squelch build errors from perl.h
- Add perl_requires
- Fix --version output (copy submakefiles from kernel-source)
- Pass SUSE rpm optflags into make as EXTRA_CFLAGS not CFLAGS
- Stop building with V=1, make output easier to parse
* Tue Dec 25 2012 tonyj@suse.com
- Add /etc/bash_completion.d/perf to %%files (fix build error)
* Wed May 16 2012 toganm@opensuse.org
- Fix build for factory
  * added flex and bison to buildrequires
* Thu May  5 2011 idoenmez@novell.com
- Also copy arch/lib to fix compilation on x86-64
- Correctly depend on libdw-devel to fix dwarf support
- Add newt-devel dependency to enable text user interface
- Re-enable as-needed support since it works now
* Tue Mar  9 2010 tonyj@novell.com
- 2.6.33 changes
  add perf-bench, perf-buildid-list, perf-diff, perf-kmem, perf-probe and
  perf-trace-perl
  [Still pending, update of libdwarf to version > 20081231]
* Thu Nov  5 2009 tonyj@novell.com
- 2.6.32 changes
  add perf-sched, perf-timechart and perf-trace man pages
* Wed Aug 26 2009 aj@suse.de
- Remove libbfd.patch since it does not apply and use
  SUSE_ASNEEDED=0 instead.
- Set flag for asciidoc version 8.
* Sun Aug  2 2009 tonyj@suse.de
- Initial checkin of Performance Counters for Linux (PCL) userspace.
  This builds tools/perf out of kernel-source package and requires
  kernel >= 2.6.31
